
CREATE TABLE ALS_AUTHORS ( 
  ID                   NUMBER (10)   NOT NULL, 
  FIRST_NAME           VARCHAR2 (30), 
  LAST_NAME            VARCHAR2 (40), 
  INITIALS             VARCHAR2 (15), 
  COUNTRY_OF_BIRTH     VARCHAR2 (2), 
  COUNTRY_OF_LIVING    VARCHAR2 (2), 
  LOCATION_IN_COUNTRY  VARCHAR2 (50), 
  BIOGRAPHY            VARCHAR2 (2000), 
  CONSTRAINT ATR_PK
  PRIMARY KEY ( ID ) ) ; 

COMMENT ON COLUMN ALS_AUTHORS.BIOGRAPHY IS 'Some details on the author like "He has been a J2EE Architect since 1997"';
COMMENT ON COLUMN ALS_AUTHORS.LOCATION_IN_COUNTRY IS 'Indicate city or state within country.';

CREATE TABLE ALS_AUTHORSHIPS ( 
  ID                NUMBER (10)   NOT NULL, 
  CONTRIBUTOR_TYPE  NUMBER (1), 
  BOK_ID            NUMBER (10)   NOT NULL, 
  ATR_ID            NUMBER (10)   NOT NULL, 
  CONSTRAINT ATP_PK
  PRIMARY KEY ( ID ) ) ; 

COMMENT ON COLUMN ALS_AUTHORSHIPS.CONTRIBUTOR_TYPE IS 'What kind of contribution has the author made to this book?';

CREATE TABLE ALS_BOOKS ( 
  ID               NUMBER (10)   NOT NULL, 
  COMPLEXITY       NUMBER (1), 
  ISBN             VARCHAR2 (30), 
  WEIGHT           NUMBER (4), 
  PUBLISH_MONTH    NUMBER (2), 
  FORMAT           VARCHAR2 (1), 
  TITLE            VARCHAR2 (100)  NOT NULL, 
  PUBLISH_YEAR     NUMBER (4), 
  EDITION          VARCHAR2 (50), 
  NUMBER_OF_PAGES  NUMBER (4), 
  LANGUAGE         VARCHAR2 (2), 
  BOK_SIZE         VARCHAR2 (20), 
  LEVEL_OF_DETAIL  NUMBER (1), 
  KEYWORDS         VARCHAR2 (200), 
  PBR_ID           NUMBER (10)   NOT NULL, 
  BOK_ID           NUMBER (10), 
  THUMBNAIL        BLOB,
  CONSTRAINT BOK_PK
  PRIMARY KEY ( ID ) ) ; 

COMMENT ON COLUMN ALS_BOOKS.BOK_SIZE IS 'Physical size (cm x cm x cm) of the book';
COMMENT ON COLUMN ALS_BOOKS.EDITION IS 'Indication of the edition (e.g  first edition, fourth edition)';
COMMENT ON COLUMN ALS_BOOKS.KEYWORDS IS 'Which keywords are logically associated with the book?';
COMMENT ON COLUMN ALS_BOOKS.LANGUAGE IS 'What (natural) langage is the book written in';

CREATE TABLE ALS_COPIES ( 
  ID            NUMBER (10)   NOT NULL, 
  ORDER_DATE    DATE, 
  ARRIVAL_DATE  DATE, 
  PRICE         NUMBER (6,2), 
  CONDITION     VARCHAR2 (1)  NOT NULL, 
  LABEL         VARCHAR2 (10)  NOT NULL, 
  STATUS        VARCHAR2 (1)  NOT NULL, 
  BOK_ID        NUMBER (10)   NOT NULL, 
  CONSTRAINT COY_PK
  PRIMARY KEY ( ID ) ) ; 

COMMENT ON COLUMN ALS_COPIES.CONDITION IS 'The physical condition of this bookcopy, from pristine to complete exhausted';
COMMENT ON COLUMN ALS_COPIES.LABEL IS 'System generated identification for each physical bookcopy; should be on te book itself (stamp, label)';
COMMENT ON COLUMN ALS_COPIES.STATUS IS 'What is the situation with the book-copy: is it already received, is it being used, is it obsolete because it is out of fashion or is it discarded because of its physical condition or is it perhaps lost?';

CREATE TABLE "ALS_PUBLISHERS"
(
"ID" NUMBER (10,0) NOT NULL,
"WEBSITE" VARCHAR2 (50),
"NAME" VARCHAR2 (50),
"COUNTRY" VARCHAR2 (2),
"LOCATION_IN_COUNTRY" VARCHAR2 (50),
"LOGO" BLOB,
  CONSTRAINT PBR_PK
  PRIMARY KEY ( ID ) 
)
;
CREATE TABLE "ALS_BOOK_RECOMMENDATIONS"
(
"ID" NUMBER (5) NOT NULL,
"BOK_ID" NUMBER (5) NOT NULL,
"STF_ID" NUMBER (3),
"CREATION_DATE" DATE NOT NULL,
"MOTIVATION" VARCHAR2 (2000),
"TURNED_TO_ORDER" DATE,
  CONSTRAINT REN_PK
  PRIMARY KEY ( ID ) 
)
;
CREATE TABLE "ALS_BORROWINGS"
(
  ID            NUMBER (7) NOT NULL,
  COY_ID        NUMBER (6) NOT NULL,
  START_DATE    DATE,
  END_DATE      DATE,
  DESCRIPTION   VARCHAR2 (2000),
  STF_ID        NUMBER (3),
  CONSTRAINT BOG_PK
  PRIMARY KEY ( ID ) 
)
;


ALTER TABLE "ALS_COPIES"
ADD CONSTRAINT "COY_BOK_FK" FOREIGN KEY
(
"BOK_ID"
)
REFERENCES "ALS_BOOKS"
(
"ID"
)
DISABLE
;
ALTER TABLE "ALS_AUTHORSHIPS"
ADD CONSTRAINT "ATP_ATR_FK" FOREIGN KEY
(
"ATR_ID"
)
REFERENCES "ALS_AUTHORS"
(
"ID"
)
DISABLE
;
ALTER TABLE "ALS_AUTHORSHIPS"
ADD CONSTRAINT "ATP_BOK_FK" FOREIGN KEY
(
"BOK_ID"
)
REFERENCES "ALS_BOOKS"
(
"ID"
)
DISABLE
;
ALTER TABLE "ALS_BOOKS"
ADD CONSTRAINT "BOK_BOK_FK" FOREIGN KEY
(
"BOK_ID"
)
REFERENCES "ALS_BOOKS"
(
"ID"
)
DISABLE
;
ALTER TABLE "ALS_BOOKS"
ADD CONSTRAINT "BOK_PBR_FK" FOREIGN KEY
(
"PBR_ID"
)
REFERENCES "ALS_PUBLISHERS"
(
"ID"
)
DISABLE
;

REM ALTER TABLE "ALS_AMIS_STAFF"
REM ADD CONSTRAINT "AMIS_STAFF_PK1" PRIMARY KEY
REM (
REM "ID"
REM )
REM  DISABLE
REM ;

REM ALTER TABLE "ALS_BOOK_RECOMMENDATIONS"
REM ADD CONSTRAINT "BOOK_RECOMMENDATIONS_FK" FOREIGN KEY
REM (
REM "STF_ID"
REM )
REM REFERENCES "ALS_AMIS_STAFF"
REM (
REM "ID"
REM ) DISABLE
REM ;
ALTER TABLE "ALS_BOOK_RECOMMENDATIONS"
ADD CONSTRAINT "REN_BOK_FK" FOREIGN KEY
(
"BOK_ID"
)
REFERENCES "ALS_BOOKS"
(
"ID"
) DISABLE
;
ALTER TABLE "ALS_BORROWINGS"
ADD CONSTRAINT "BOG_COY_FK" FOREIGN KEY
(
"COY_ID"
)
REFERENCES "ALS_COPIES"
(
"ID"
) DISABLE
;


REM ALTER TABLE "ALS_BOOK_USAGES"
REM ADD CONSTRAINT "BOOK_USAGE_FK" FOREIGN KEY
REM (
REM "STF_ID"
REM )
REM REFERENCES "ALS_AMIS_STAFF"
REM (
REM "ID"
REM ) DISABLE
REM ;
REM ALTER TABLE "ALS_BORROWINGS"
REM ADD CONSTRAINT "ALS_BORROWINGS_FK2" FOREIGN KEY
REM (
REM "STF_ID"
REM )
REM REFERENCES "ALS_AMIS_STAFF"
REM (
REM "ID"
REM ) DISABLE
REM;
